.. _installing-qt:

Installing PyQt or PySide
=========================

If you are using Linux, PyQt and PySide will typically be available in the
built-in package manager. For example, if you are using Ubuntu, then you can do::

    sudo apt-get install python-qt5

for Python 2, and::

    sudo apt-get install python3-pyqt5

for Python 3. If you are using MacOS X, then if you are using MacPorts to
manage your Python installation, you can do::

    sudo port install py35-pyqt5

assuming you are using Python 3.5 (modify the ``py35`` version as needed).
